@@ -11,7 +11,6 @@ module Graphics.Rendering.Chart.Backend
   (
   -- * The backend Monad
     ChartBackend
-  , CRender
   
   -- * Backend Operations
   , fillPath
@@ -49,8 +48,6 @@ module Graphics.Rendering.Chart.Backend
   , FontSlant(..)
   , FontStyle(..)
 
-  , defaultFontStyle
-  
   , HTextAnchor(..)
   , VTextAnchor(..)
 
